===============
unittest2doc
===============

English | `中文 <README.zh.rst>`_

Convert Python unit tests to documentation.

Installation
------------

.. code-block:: bash

    pip install unittest2doc

Usage
-----

No explanation is better than a direct example. Please refer to https://fmajor.github.io/unittest2doc/